@@ -1,3 +1,3 @@
-from email import utils
 from xtremcache import cachemanager
-from xtremcache import exceptions
\ No newline at end of file
+from xtremcache import exceptions
+from xtremcache import log_level
